==> messagelib-17.04.2.tar.xz: messagelib-17.04.2/messageviewer/src/findbar/findbarsourceview.h <==
/* Copyright (C) 2011-2016 Laurent Montel <montel@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef FINDBARSOURCEVIEW_H
#define FINDBARSOURCEVIEW_H

#include <WebEngineViewer/FindBarBase>

class QPlainTextEdit;

namespace MessageViewer
{
class FindBarSourceView : public WebEngineViewer::FindBarBase
{
    Q_OBJECT

public:
    explicit FindBarSourceView(QPlainTextEdit *view, QWidget *parent = nullptr);
    ~FindBarSourceView();

private:
    explicit FindBarSourceView(QWidget *parent)
    {
        Q_UNUSED(parent);
    }
    void clearSelections() Q_DECL_OVERRIDE;
    void searchText(bool backward, bool isAutoSearch) Q_DECL_OVERRIDE;
    void updateHighLight(bool) Q_DECL_OVERRIDE;
    void updateSensitivity(bool) Q_DECL_OVERRIDE;

private:
    QPlainTextEdit *mView;
};
}

#endif /* FINDBARSOURCEVIEW_H */

==> messagelib-20.04.2.tar.xz: messagelib-20.04.2/messageviewer/src/findbar/findbarsourceview.h <==
/* Copyright (C) 2011-2020 Laurent Montel <montel@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef FINDBARSOURCEVIEW_H
#define FINDBARSOURCEVIEW_H

#include <WebEngineViewer/FindBarBase>

class QPlainTextEdit;

namespace MessageViewer {
class FindBarSourceView : public WebEngineViewer::FindBarBase
{
    Q_OBJECT

public:
    explicit FindBarSourceView(QPlainTextEdit *view, QWidget *parent = nullptr);
    ~FindBarSourceView() override;

private:
    explicit FindBarSourceView(QWidget *parent)
    {
        Q_UNUSED(parent);
    }

    void clearSelections() override;
    void searchText(bool backward, bool isAutoSearch) override;
    void updateHighLight(bool) override;
    void updateSensitivity(bool) override;

private:
    QPlainTextEdit *mView = nullptr;
};
}

#endif /* FINDBARSOURCEVIEW_H */
